@@ -1,4 +1,4 @@
-# Copyright (C) 2009- 2010	Dirk Eddelbuettel and Romain Francois
+# Copyright (C) 2009 - 2011 Dirk Eddelbuettel and Romain Francois
 #
 # This file is part of Rcpp.
 #
@@ -18,7 +18,9 @@
 .dummyInstancePointer <- new.env() # just something permanent
 
 .onLoad <- function(libname, pkgname){
-    .Call("init_Rcpp_cache", PACKAGE = "Rcpp" )
+    ## Call to init_Rcpp_cache is not needed here as it is called in
+    ## R_init_Rcpp.  Calling it twice is potentially destructive
+#    .Call("init_Rcpp_cache", PACKAGE = "Rcpp" )
     minimum_svn_rev <- packageDescription( pkgname )[["MinimumSvnRev"]]
     # if( as.integer(R.version[["svn rev"]]) < as.integer(minimum_svn_rev)){
     #     packageStartupMessage(gettextf(paste("R version (%s) older than minimum required (%s)",
