@@ -2,7 +2,7 @@
 //
 // sum.h: Rcpp R/C++ interface class library -- sum
 //
-// Copyright (C) 2010 Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2010 - 2011 Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -30,8 +30,9 @@ class Sum : public Lazy< typename Rcpp::traits::storage_type<RTYPE>::type , Sum<
 public:
 	typedef typename Rcpp::VectorBase<RTYPE,NA,T> VEC_TYPE ;
 	typedef typename Rcpp::traits::storage_type<RTYPE>::type STORAGE ;
-	
-	Sum( const VEC_TYPE& object_ ) : object(object_){}
+	typedef typename Rcpp::traits::Extractor< RTYPE, NA, T>::type VEC_EXT ;
+		
+	Sum( const VEC_TYPE& object_ ) : object(object_.get_ref()){}
 	
 	STORAGE get() const {
 		STORAGE result = 0 ;
@@ -46,16 +47,38 @@ public:
 		return result ;
 	}         
 private:
-	const VEC_TYPE& object ;
+	const VEC_EXT& object ;
 } ;
+// RTYPE = REALSXP
+template <bool NA, typename T>
+class Sum<REALSXP,NA,T> : public Lazy< double , Sum<REALSXP,NA,T> > {
+public:
+	typedef typename Rcpp::VectorBase<REALSXP,NA,T> VEC_TYPE ;
+	typedef typename Rcpp::traits::Extractor< REALSXP, NA, T>::type VEC_EXT ;
+		
+	Sum( const VEC_TYPE& object_ ) : object(object_.get_ref()){}
+	
+	double get() const {
+		double result = 0 ;
+		int n = object.size() ;
+		for( int i=0; i<n; i++){
+		   result += object[i] ;
+		}
+		return result ;
+	}         
+private:
+	const VEC_EXT& object ;
+} ;
+
 
 template <int RTYPE, typename T>
 class Sum<RTYPE,false,T> : public Lazy< typename Rcpp::traits::storage_type<RTYPE>::type , Sum<RTYPE,false,T> > {
 public:
 	typedef typename Rcpp::VectorBase<RTYPE,false,T> VEC_TYPE ;
 	typedef typename Rcpp::traits::storage_type<RTYPE>::type STORAGE ;
+	typedef typename Rcpp::traits::Extractor< RTYPE, false, T>::type VEC_EXT ;
 	
-	Sum( const VEC_TYPE& object_ ) : object(object_){}
+	Sum( const VEC_TYPE& object_ ) : object(object_.get_ref()){}
 	
 	STORAGE get() const {
 		STORAGE result = 0 ;
@@ -66,7 +89,7 @@ public:
 		return result ;
 	}         
 private:
-	const VEC_TYPE& object ;
+	const VEC_EXT& object ;
 } ;
 
 } // sugar
